@@ -1,9 +1,11 @@
-import midata
+from .dataarray import *
+#import midata
 from .midata import *
 from .util import ncutil
 from .dimvariable import DimVariable
 from .util import *
 
 __all__ = ['DimVariable']
+__all__ += dataarray.__all__
 __all__ += midata.__all__
 __all__ += util.__all__
\ No newline at end of file
