@@ -7,9 +7,11 @@
 from org.meteoinfo.data.meteodata import MeteoDataType
 from org.meteoinfo.data.meteodata.netcdf import NCUtil
 from org.meteoinfo.data.dimarray import DimensionType, Dimension
+from org.meteoinfo.jython import JythonUtil
 from ucar.ma2 import DataType as NCDataType
 from ucar.nc2 import Attribute as NCAttribute
 from ucar.nc2 import Variable as NCVariable
+
 from dimvariable import DimVariable, TDimVariable
 from mipylib.geolib.milayer import MILayer, MIXYListData
 from mipylib.dataframe.dataframe import DataFrame
@@ -32,6 +34,7 @@ class DimDataFile(object):
         self.access = access
         self.ncfile = ncfile
         self._variables = []
+        self._coordinates = []
         if not dataset is None:
             self.filename = dataset.getFileName()
             self.nvar = dataset.getDataInfo().getVariableNum()
@@ -39,9 +42,15 @@ class DimDataFile(object):
             self.proj = dataset.getProjectionInfo()
             self.projection = self.proj
             for v in dataset.getDataInfo().getVariables():
-                self._variables.append(DimVariable.factory(v, self))
+                dim_var = DimVariable.factory(v, self)
+                self._variables.append(dim_var)
+                setattr(self, dim_var.name, dim_var)
+                if dim_var._coordinate:
+                    self._coordinates.append(dim_var)
+
         self.arldata = arldata
         self.bufrdata = bufrdata
+
         
     def __getitem__(self, key):
         if isinstance(key, basestring):
@@ -181,6 +190,25 @@ class DimDataFile(object):
         Get all variable names.
         """
         return self.dataset.getDataInfo().getVariableNames()
+
+    @property
+    def data_vars(self):
+        """Get data variables"""
+        vars = []
+        for var in self._variables:
+            if not var._coordinate:
+                vars.append(var)
+        return vars
+
+    @property
+    def coordinates(self):
+        """Get all coordinates"""
+        return self._coordinates
+
+    @property
+    def coordnames(self):
+        """Get all coordinate names"""
+        return self.dataset.getDataInfo().getCoordinateNames()
         
     def read(self, varname, origin=None, size=None, stride=None):
         """
@@ -313,12 +341,13 @@ class DimDataFile(object):
         
         :returns: (*datetime*) The time
         """
-        t = self.dataset.getDataInfo().getTimes().get(idx)
+        t = self.dataset.getDataInfo().getTimes().getDate(idx)
         if t is None:
             return None
 
         t = miutil.pydate(t)
         return t
+
         
     def gettimes(self):
         """
@@ -328,10 +357,10 @@ class DimDataFile(object):
         if tt is None:
             return None
 
-        times = []
-        for t in tt:
-            times.append(miutil.pydate(t))
-        return times
+        #tt = JythonUtil.toDateTime(tt)
+
+        return np.NDArray(tt)
+
         
     def bigendian(self, big_endian):
         """
