@@ -17,10 +17,50 @@ from org.meteoinfo.data.meteodata.netcdf import NCUtil
 from org.meteoinfo.ndarray import DataType
 
 import mipylib.numeric as np
+from .dataarray import DimArray
+from .dataarray import DateTimeAccessor
 import mipylib.miutil as miutil
 import datetime
 import numbers
 import warnings
+import re
+import keyword
+
+
+def to_valid_variable_name(name):
+    """
+    Rename variable name to a valid python variable name
+
+    Parameters
+    ----------
+    name : str
+        Input variable name
+
+    Returns
+    -------
+    str
+        Valid python variable name
+    """
+    if not name:
+        return "_"
+
+    if bool(re.search(ur'[\u4e00-\u9fff]', name)):
+        return name
+
+    # Replace invalid chars with underscore
+    name = re.sub(r"[^a-zA-Z0-9_]", "_", name)
+    name = re.sub(r"_+", "_", name).strip("_")
+    if not name:
+        return "_"
+
+    if name[0].isdigit():
+        name = "_" + name
+
+    if keyword.iskeyword(name):
+        name += "_"
+
+    return name
+
 
 # Dimension variable
 class DimVariable(object):
@@ -41,19 +81,25 @@ class DimVariable(object):
         self._variable = variable
         self.dataset = dataset
         self.ncvariable = ncvariable
+        self._coordinate = False
         if not variable is None:
-            self._name = variable.getName()
+            self._real_name = variable.getName()
+            self._name = to_valid_variable_name(self._real_name)
             self.dtype = np.dtype.fromjava(variable.getDataType())
             self.dims = variable.getDimensions()
             self.ndim = variable.getDimNumber()
             self.attributes = variable.getAttributes()
+            self._coordinate = variable.isDimVar()
         elif not ncvariable is None:
-            self._name = ncvariable.getFullName()
+            self._real_name = ncvariable.getFullName()
+            self._name = to_valid_variable_name(self._real_name)
             self.dtype = ncvariable.getDataType()
             self.dims = ncvariable.getDimensions()
             self.ndim = len(self.dims)
             self.attributes = list(ncvariable.getAttributes())
+            self._coordinate = ncvariable.isCoordinateVariable()
         else:
+            self._real_name = None
             self._name = None
             self.dtype = None
             self.dims = None
@@ -76,13 +122,24 @@ class DimVariable(object):
 
     @property
     def short_name(self):
+        s_name = None
         if self._variable is not None:
-            return self._variable.getShortName()
+            s_name = self._variable.getShortName()
+        elif self.ncvariable is not None:
+            s_name = self.ncvariable.getShortName()
 
-        if self.ncvariable is not None:
-            return self.ncvariable.getShortName()
+        s_name = to_valid_variable_name(s_name)
+        return s_name
 
-        return None
+    @property
+    def real_short_name(self):
+        s_name = None
+        if self._variable is not None:
+            s_name = self._variable.getShortName()
+        elif self.ncvariable is not None:
+            s_name = self.ncvariable.getShortName()
+
+        return s_name
             
     def __len__(self):
         len = 1
@@ -270,6 +327,10 @@ class DimVariable(object):
                         tlist.append(idx)
                     ranges.append(tlist)
                     k = tlist
+            elif isinstance(k, np.NDArray):
+                onlyrange = False
+                isrange = False
+                ranges.append(k._array)
             elif isinstance(k, basestring):
                 dim = self._variable.getDimension(i)
                 kvalues = k.split(':')
@@ -316,16 +377,21 @@ class DimVariable(object):
                 rr = Range(sidx, eidx, abs(step))
                 ranges.append(rr)
             else:
-                if len(k) > 1:
+                if isinstance(k, np.NDArray):
+                    dim = self._variable.getDimension(i)
+                    dim = dim.extract(k._array)
+                    #dim.setReverse(False)
+                    dims.append(dim)
+                elif len(k) > 1:
                     dim = self._variable.getDimension(i)
                     dim = dim.extract(k)
                     #dim.setReverse(False)
                     dims.append(dim)
 
         if onlyrange:
-            rr = self.dataset.dataset.read(self.name, ranges)
+            rr = self.dataset.dataset.read(self._real_name, ranges)
         else:
-            rr = self.dataset.dataset.take(self.name, ranges)
+            rr = self.dataset.dataset.take(self._real_name, ranges)
         if rr.getSize() == 1:
             iter = rr.getIndexIterator()
             return iter.getObjectNext()
@@ -340,7 +406,7 @@ class DimVariable(object):
                 array = np.array(rrr)
             else:
                 array = np.array(rr)
-            data = np.DimArray(array, dims, self.dataset.proj)
+            data = DimArray(array, dims, self.dataset.proj)
             return data
     
     def read(self):
@@ -348,7 +414,20 @@ class DimVariable(object):
         Read data array.
         :return: (*array*) Data array.
         """
-        return np.array(self.dataset.read(self.name))
+        return np.array(self.dataset.read(self._real_name))
+
+    @property
+    def values(self):
+        """Read data array"""
+        return np.array(self.dataset.read(self._real_name))
+
+    @property
+    def dt(self):
+        """date time accessor"""
+        if self._variable.hasCachedData() and self.dtype == np.dtype.datetime:
+            return DateTimeAccessor(self._variable.getCachedData())
+        else:
+            return None
 
     def get_pack_paras(self):
         """
@@ -598,10 +677,12 @@ class StructureVariable(DimVariable):
                 datainfo.reOpen()
 
             self._ncfile = datainfo.getFile()
-            self._ncvar = self._ncfile.findVariable(self.name)
+            self._ncvar = self._ncfile.findVariable(self._real_name)
             self._variables = []
             for var in self._ncvar.getVariables():
-                self._variables.append(MemberVariable.factory(NCUtil.convertVariable(var), dataset, self))
+                mvar = MemberVariable.factory(NCUtil.convertVariable(var), dataset, self)
+                self._variables.append(mvar)
+                setattr(self, mvar.short_name, mvar)
 
     def __getitem__(self, key):
         if isinstance(key, basestring):
@@ -615,7 +696,7 @@ class StructureVariable(DimVariable):
 
             raise ValueError(key + ' is not a variable name')
         else:
-            return np.array(self.dataset.read(self.name))
+            return np.array(self.dataset.read(self._real_name))
 
     @property
     def variables(self):
@@ -666,7 +747,7 @@ class MemberVariable(DimVariable):
                 datainfo.reOpen()
 
             self._ncfile = datainfo.getFile()
-            self._ncvar = self._ncfile.findVariable(self.name)
+            self._ncvar = self._ncfile.findVariable(self._real_name)
 
     def __getitem__(self, key):
         """
@@ -705,12 +786,12 @@ class MemberVariable(DimVariable):
         missing_value, scale_factor, add_offset = self.get_pack_paras()
         is_structure = isinstance(a, ArrayStructure)
         if is_structure:
-            r = NCUtil.readSequence(a, self.short_name)
+            r = NCUtil.readSequence(a, self.real_short_name)
         else:
             if seq is None:
-                r = NCUtil.readSequenceRecord(a, self.short_name, record, missing_value)
+                r = NCUtil.readSequenceRecord(a, self.real_short_name, record, missing_value)
             else:
-                r = NCUtil.readSequence(a, self.short_name, seq)
+                r = NCUtil.readSequence(a, self.real_short_name, seq)
 
         if r is None:
             return None
@@ -935,11 +1016,11 @@ class TDimVariable(object):
                     nindices = tuple(nindices)
                     aa = var.__getitem__(nindices)
                     if si == ei:
-                        if isinstance(aa, np.DimArray):
+                        if isinstance(aa, DimArray):
                             aa.addtdim(self.dataset.gettime(si))
                         else:
                             aa = np.array([aa])
-                            aa = np.DimArray(aa)
+                            aa = DimArray(aa)
                             aa.addtdim(self.dataset.gettime(si))
                     if data is None:
                         data = aa
@@ -960,11 +1041,11 @@ class TDimVariable(object):
                 nindices = tuple(nindices)
                 aa = var.__getitem__(nindices)
                 if si == ei and eidx != sidx:
-                    if isinstance(aa, np.DimArray):
+                    if isinstance(aa, DimArray):
                         aa.addtdim(self.dataset.gettime(si))
                     else:
                         aa = np.array([aa])
-                        aa = np.DimArray(aa)
+                        aa = DimArray(aa)
                         aa.addtdim(self.dataset.gettime(si))
                 if data is None:
                     data = aa
@@ -997,7 +1078,7 @@ class TDimVariable(object):
                 else:
                     data = np.concatenate([data, aa])
                 
-        if isinstance(data, np.DimArray):
+        if isinstance(data, DimArray):
             return data
         else:
             if isinstance(aa, numbers.Number):
@@ -1005,5 +1086,5 @@ class TDimVariable(object):
 
             dims = aa.dims
             dims[0].setDimValues(times)
-            r = np.DimArray(data, dims, aa.proj)
+            r = DimArray(data, dims, aa.proj)
             return r
\ No newline at end of file
